@@ -2,11 +2,12 @@ import time
 from .game import Game, SeekerException, HiderException
 from .hider import Hider
 from .seeker import Seeker
-
 import random
 
+DEFAULT_NUM_GAMES = 15
+
 class Match:
-    def __init__(self, SeekerClass, HiderClass, games=15):
+    def __init__(self, SeekerClass, HiderClass, games=DEFAULT_NUM_GAMES):
         self._count = 0
         self._valid_seeds = [1, 2, 5, 6, 7, 8, 11, 12, 14, 16, 19, 20, 22, 24, 25, 26, 27, 28, 29, 30, 31, 32, 35, 38, 39, 41, 43, 45,
                     47, 48, 49, 51, 53, 55, 62, 63, 67, 69, 70, 71, 72, 75, 77, 79, 81, 82, 84, 86, 87, 90, 91, 92, 93, 95,
@@ -77,4 +78,15 @@ class Match:
             "seeker_info": '\n'.join(self._seeker_info),
             "hider_info": '\n'.join(self._hider_info),
         }
+        return result
+
+    def get_bad_launch(self, type, msg):
+        result = {
+            "seeker_points": 0,
+            "hider_points": 0,
+            "seeker_errors": DEFAULT_NUM_GAMES if type == Game.SEEKER else 0,
+            "hider_errors": DEFAULT_NUM_GAMES if type == Game.Hider else 0,
+            "seeker_info": f"{msg}. {'Does not affect seeker\'s score' if type != Game.SEEKER else ''}",
+            "hider_info": f"{msg}. {'Does not affect hider\'s score' if type != Game.HIDER else ''}",
+        }
         return result
\ No newline at end of file
